@@ -42,7 +42,7 @@ def test_common_prefix():
     nits = lint.lint_metrics(all_metrics.value)
 
     assert len(nits) == 1
-    assert nits[0][0] == "COMMON_PREFIX"
+    assert nits[0].check_name == "COMMON_PREFIX"
 
     # Now make sure the override works
     contents[0]["no_lint"] = ["COMMON_PREFIX"]
@@ -81,7 +81,7 @@ def test_unit_in_name():
     nits = lint.lint_metrics(all_metrics.value)
 
     assert len(nits) == 3
-    assert all(nit[0] == "UNIT_IN_NAME" for nit in nits)
+    assert all(nit.check_name == "UNIT_IN_NAME" for nit in nits)
 
     # Now make sure the override works
     contents[0]["telemetry"]["network_latency_ms"]["no_lint"] = ["UNIT_IN_NAME"]
@@ -105,7 +105,7 @@ def test_category_generic():
     nits = lint.lint_metrics(all_metrics.value)
 
     assert len(nits) == 1
-    assert nits[0][0] == "CATEGORY_GENERIC"
+    assert nits[0].check_name == "CATEGORY_GENERIC"
 
     contents[0]["no_lint"] = ["CATEGORY_GENERIC"]
     all_metrics = parser.parse_objects(contents)
@@ -147,7 +147,7 @@ def test_combined():
 
     assert len(nits) == 5
     assert set(["COMMON_PREFIX", "CATEGORY_GENERIC", "UNIT_IN_NAME"]) == set(
-        v[0] for v in nits
+        v.check_name for v in nits
     )
 
 
@@ -172,8 +172,8 @@ def test_superfluous():
     nits = lint.lint_metrics(all_metrics.value)
 
     assert len(nits) == 1
-    assert all(nit[0] == "SUPERFLUOUS_NO_LINT" for nit in nits)
-    assert all("UNIT_IN_NAME" in nit[2] for nit in nits)
+    assert all(nit.check_name == "SUPERFLUOUS_NO_LINT" for nit in nits)
+    assert all("UNIT_IN_NAME" in nit.msg for nit in nits)
 
 
 def test_baseline_restriction():
@@ -195,7 +195,7 @@ def test_baseline_restriction():
     nits = lint.lint_metrics(all_metrics.value)
 
     assert len(nits) == 2
-    assert set(["BASELINE_PING"]) == set(v[0] for v in nits)
+    assert set(["BASELINE_PING"]) == set(v.check_name for v in nits)
 
 
 def test_misspelling_pings():
@@ -217,7 +217,7 @@ def test_misspelling_pings():
     nits = lint.lint_metrics(all_metrics.value)
 
     assert len(nits) == 2
-    assert set(["MISSPELLED_PING"]) == set(v[0] for v in nits)
+    assert set(["MISSPELLED_PING"]) == set(v.check_name for v in nits)
 
 
 def test_yaml_lint():
@@ -229,3 +229,58 @@ def test_yaml_lint():
     assert len(nits) == 3
     # The second rule is empty because it's a syntax error.
     assert set(["indentation", None, "trailing-spaces"]) == set(v.rule for v in nits)
+
+
+def test_user_lifetime_expiration():
+    """Test that expiring 'user' lifetime metrics generate a warning."""
+    contents = [
+        {
+            "user_data": {
+                "counter": {
+                    "type": "counter",
+                    "lifetime": "user",
+                    "expires": "2100-01-01",
+                },
+                "string": {"type": "string", "lifetime": "user", "expires": "never"},
+                "other": {"type": "string", "lifetime": "application"},
+            }
+        }
+    ]
+
+    contents = [util.add_required(x) for x in contents]
+    all_metrics = parser.parse_objects(contents)
+
+    errs = list(all_metrics)
+    assert len(errs) == 0
+
+    nits = lint.lint_metrics(all_metrics.value)
+
+    assert len(nits) == 1
+    assert set(["USER_LIFETIME_EXPIRATION"]) == set(v.check_name for v in nits)
+
+
+def test_warnings():
+    # SUPERFLUOUS_NO_LINT is a warning, so it shouldn't return an error code
+    contents = [
+        {
+            "user_data": {
+                "counter": {
+                    "type": "counter",
+                    "send_in_pings": ["metrics"],
+                    "no_lint": ["UNIT_IN_NAME"],
+                },
+            }
+        }
+    ]
+
+    contents = [util.add_required(x) for x in contents]
+    all_metrics = parser.parse_objects(contents)
+
+    errs = list(all_metrics)
+    assert len(errs) == 0
+
+    nits = lint.lint_metrics(all_metrics.value)
+
+    assert not any(x.check_type == lint.CheckType.error for x in nits)
+    assert len(nits) == 1
+    assert nits[0].check_name == "SUPERFLUOUS_NO_LINT"
